package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(``P`!````,)P$"#0```#8NP```````#0`(``'
M`"@`&P`:``8````T````-(`$"#2`!`C@````X`````4````$`````P```!0!
M```4@00(%($$"!,````3````!`````$````!``````````"`!`@`@`0('+8`
M`!RV```%`````!````$````<M@``'$8%"!Q&!0AP`@``U!(```8`````$```
M`@```#"V```P1@4(,$8%"/@```#X````!@````0````$````*`$``"B!!`@H
M@00((````"`````$````!````%'E=&0```````````````````````````8`
M```$````+VQI8B]L9"UL:6YU>"YS;RXR```$````$`````$```!'3E4`````
M``(````&````"````&$```!S````"@``````````````0@````````!'````
M1@``````````````60```#T````X````2@````,```!7`````````#````!>
M````5````&D```!K````9@````0````K```````````````I````8@```$4`
M````````;P```&,```!(````9`````@`````````40```'(````!````3```
M```````>`````````'``````````4````&T``````````````&4````G````
M3@```#D``````````````&X````T````/P```$0``````````````!(`````
M````/@``````````````(@`````````;````+P````L````Q````*````%,`
M`````````````%H```!/````.P```%T```!+````.@```#,`````````#```
M`````````````````%4```!L`````````$,```!<````00```#P````F````
M````````````````````````````````````````````````````````````
M`````````$T```````````````````````````````X`````````#P```!0`
M``!?````````````````````$P``````````````$0`````````8````````
M`````````````````%@`````````5@````````!G```````````````0````
M````````````````&@`````````E````:````",````'`````````"X````D
M````#0```!P`````````8````"``````````&0````D``````````````$``
M````````,@```!T````M`````````'$```!;`````````$D````&````````
M``````!J````````````````````````````````````(0``````````````
M%P`````````U`````````"H`````````````````````````%@`````````5
M`````````%(`````````!0```````````````````&$````V`````@``````
M```?````+````#<````E````30````@````(`````!`0!"5`!("H$0`!HH9!
MJ$````)+*$0I.*(R1XH$#(A-````3P```````````````````%(```!4````
M50````````!6````5P````````!8````60```%H`````````6P``````````
M`````````%P```!?``````````````!@````8@```&,```!E`````````&<`
M``!J`````````&P```!M````;@```'``````````R-6R<5GH[>SF_S"BSMY'
M+:/@^TGJT^\.I]VC:R_%F[;;S>.>A_F<@6L)0]8-.I<+Q8D%D`T4XIXA_^0.
ML@&+;\2YG$!K?YI\?ZF<FV[%WQ_9<5@<N^.2?-1DU'RM2^/`,F+;[>&G`@IF
MK\QF8!;)67OP2FOB1\8!0T75[$?L,SI]08[%PN4_++>`A63RV],=^J%L8+F-
M\0X`````````````````````-0,````````Q````$@```+$`````````#0``
M`!(```"#`P```````#$````2````;@,````````^````$@```*$!````````
M+P```!(```!Z`@```````$H%```2````$0``````````````(````"``````
M`````````"````!T`P```````(P"```2````C0$````````-````$@```",$
M````````10```!(```!N`0````````T````2````@`$````````+````$@``
M`$X#````````Q@```!(````>`P```````!X!```2````^`(```````"I````
M$@```"P"````````&00``!(```#]`````````#4#```2````'`(```````!-
M````$@```)\#````````6````!(```#*`0```````&\!```2````!P0`````
M``##`0``$@```-<"````````>P```!(``````P```````'8````2````F`(`
M``````#-`0``$@```.H!````````%@```!(```"F`0```````/L````2````
M-0(```````#A`@``$@```"T$````````10```!(```#Y`P```````#X````2
M````+P$````````-````$@```+H#````````F````!(````T`````````(T`
M```2````P@,```````!`````$@```%T!````````9P$``!(```#(````````
M`"$'```2````YP,```````#>````$@```+,#````````1@```!(```#@`P``
M`````'P$```2````F`,```````"O````$@```&<#````````.@```!(```#K
M!````````"L!```2````00$```````!Y`0``$@```-`#````````#````!(`
M``!<`@```````%0#```2````10,```````!B````$@```.L"````````:P``
M`!(```!.`@````````,4```2````I@,```````!T`0``$@```)$"````````
MD@$``!(```"K`0```````.0````2````5@,````````@````$@```*T#````
M````.@```!(```"1`P```````!(!```2````[``````````-````$@```$(`
M````````"P```!(```#7`P```````$`````2````\0,```````"H````$@``
M`-<`````````/@```!(```#^`0````````T````2````A0(```````!@````
M$@```%`!````````I````!(```!\`P```````)L!```2````/0,````````)
M`0``$@```/$"````````YP```!(````=`0````````T````2````0P(`````
M``!&`P``$@```%0`````````=````!(```"*`P```````%4````2````V`$`
M```````6````$@```&,`````````#0```!(`````!````````$,````2````
MCP`````````-````$@```#`#````````_0```!(```!X`````````&8````2
M````"P$````````R"0``$@```+<!``"DEP0(4````!(```",!```H-@$"`0`
M```1``\`8@4``&#;!`BX6@``$0`/`&P%``"BP00(<0@``!(`#0"8!0``):<$
M"-$!```2``T`A@0``'S8!`@`````$@`.`!L$``"@2`4(!````"$`&`!>!```
MU:($"`T````2``T`)`4``'#7!`A:````$@`-`*````!TF00(4````!(````/
M!0``<$@%"``````0`!<`$04``'!(!0@`````(``7`!H$``"@2`4(!````"$`
M&`!\!```8-<$"`4````2``T`BP4``.*B!`C1`@``$@`-`*D$``#VJ`0(6```
M`!(`#0`9!```H$@%"`0````1`!@`%`0``#;4!`C@`@``$@`-`-D$```QP`0(
M/0```!(`#0#T!```;LL$"'L````2``T`300``(Q(!0@`````$`#Q_UD$``#P
M6`4(`````!``\?^3!```GLX$""P%```2``T`#P,``*38!`@$````$0`/`!4%
M```PG`0(`````!(`#0"W!```M:$$""`!```2``T`S00``/6E!`@P`0``$@`-
M```%``"(2`4(!````!$`%P!J`@``9)D$")<'```2````;P0``+.E!`A"````
M$@`-`$8$``",2`4(`````!``\?]=!0``A$@%"`0````1`!<`-`4``$+.!`A<
M````$@`-`!P%``#DG`0(1@```!(`#0!0!0``$\H$"%L!```2``T`HP(``*1(
M!0@3````$0`8`'D%``!NP`0(-`$``!(`#0`>!0``!)<$"``````2``L``&QI
M8G!E<FPN<V\N-2XQ,`!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S
M<V5S`%!E<FQ?<WES7W1E<FT`4&5R;%])<W1A=&)U9E]P='(`4&5R;%]S>7-?
M:6YI=#,`4&5R;%])97AI=%]F;&%G<U]P='(`4&5R;%]S879E7V1E<W1R=6-T
M;W)?>`!097)L7TEC;VUP8W9?<'1R`%!E<FQ?871F;W)K7VQO8VL`4&5R;%])
M8W5R<W1A8VMI;F9O7W!T<@!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO
M8V]N=&5X=`!097)L7TEP87)S97)?<'1R`%!E<FQ?879?<VAI9G0`4&5R;%]S
M=E\R<'9?9FQA9W,`4&5R;%])=&]P7V5N=E]P='(`4&5R;%])=&%I;G1E9%]P
M='(`4&5R;%]S=E]S971P=FX`4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA
M9W,`4&5R;%]):6Y?979A;%]P='(`4&5R;%]);W!?<'1R`%!E<FQ?265V86Q?
M<F]O=%]P='(`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?1W1H<E]K97E?<'1R`%!E<FQ?1V1O
M7W5N9'5M<%]P='(`4&5R;%])<&5R;%]D97-T<G5C=%]L979E;%]P='(`4&5R
M;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=8
M4P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R
M`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?
M;65M;W)Y7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS
M;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`&QS965K-C0`
M<F5A9`!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O
M<FL`97AI=`!S<')I;G1F`'-T<FYC;7``8VQO<V5D:7(`<W1R;F-P>0!?7W-T
M86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P
M:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!M
M96UC<'D`;W!E;F1I<@!?7V-T>7!E7V)?;&]C`&=E='5I9`!R96%D;&EN:P!E
M>&5C=G``<F5A9&1I<C8T`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]X<W1A=#8T`%]?;'AS=&%T-C0`;&EB
M8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!P87)?8W5R<F5N
M=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI8F-?8W-U7V9I;FD`7V9P7VAW`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT
M7V5X96-?<')O8P!P87)?9&ER;F%M90!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!S:7IE7VQO861?;65?,@!?7V1A=&%?<W1A<G0`
M>'-?:6YI=`!?7VQI8F-?8W-U7VEN:70`6%-?26YT97)N86QS7U!!4E]#3$5!
M4E-404-+`'!A<E]R;71M<&1I<@!N86UE7VQO861?;65?,@!P87)?;6MT;7!D
M:7(`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`'!A<E]I;FET7V5N
M=@!'3$E"0U\R+C``1TQ)0D-?,BXR`$=,24)#7S(N-`!'3$E"0U\R+C,`1TQ)
M0D-?,BXS+C(``````@````(``@````````````(````#```````"``0`!0``
M```````"`````@`&``8```````(````#``(````"````!P```````P`"``(`
M`@`"``(````"`````@`&`````@`"````"``"``(```````(``@``````````
M``(``@`%``````````(```````(````"``````````$``0`!``$``0`"``$`
M`0````$``0`"``$``0`!``(``0`!``$``0`!``$``0`!``$``0`!`````0`!
M``$``0`!``$````!``$``0`"`,<"```0````,````!!I:0T```8`I04``!``
M```2:6D-```%`*\%`````````0`%``4#```0`````````!1I:0T```@`N04`
M`!`````3:6D-```'`,,%```0````<AEI"0``!`#-!0``$````!)I:0T```,`
MKP4``!`````0:6D-```"`*4%````````*$<%"`8'``"@2`4(!5T``*1(!0@%
M<```.$<%"`<!```\1P4(!P(``$!'!0@'`P``1$<%"`<$``!(1P4(!P4``$Q'
M!0@'!@``4$<%"`=-``!41P4(!P<``%A'!0@'"0``7$<%"`<*``!@1P4(!PL`
M`&1'!0@'#```:$<%"`<-``!L1P4(!PX``'!'!0@'#P``=$<%"`<0``!X1P4(
M!Q$``'Q'!0@'$@``@$<%"`<3``"$1P4(!Q0``(A'!0@'%0``C$<%"`<6``"0
M1P4(!Q<``)1'!0@'&```F$<%"`<9``"<1P4(!QH``*!'!0@'&P``I$<%"`<<
M``"H1P4(!QT``*Q'!0@''@``L$<%"`<?``"T1P4(!R```+A'!0@'(0``O$<%
M"`<B``#`1P4(!VD``,1'!0@'5@``R$<%"`<C``#,1P4(!R0``-!'!0@')0``
MU$<%"`<F``#81P4(!R<``-Q'!0@'*```X$<%"`<I``#D1P4(!RH``.A'!0@'
M*P``[$<%"`<L``#P1P4(!RT``/1'!0@'+@``^$<%"`<O``#\1P4(!S````!(
M!0@',0``!$@%"`<R```(2`4(!S,```Q(!0@'-```$$@%"`<U```42`4(!S8`
M`!A(!0@'-P``'$@%"`<X```@2`4(!SD``"1(!0@'.@``*$@%"`<[```L2`4(
M!SP``#!(!0@'/0``-$@%"`<^```X2`4(!S\``#Q(!0@'0```0$@%"`=!``!$
M2`4(!T(``$A(!0@'0P``3$@%"`=$``!02`4(!T4``%1(!0@'1@``6$@%"`='
M``!<2`4(!T@``&!(!0@'20``9$@%"`=*``!H2`4(!TL``&Q(!0@'3```58GE
M4X/L!.@`````6X'#'+```(N3_/___X72=`7HC@```.B5!0``Z"!!``!86\G#
M_S4P1P4(_R4T1P4(`````/\E.$<%"&@`````Z>#_____)3Q'!0AH"````.G0
M_____R5`1P4(:!````#IP/____\E1$<%"&@8````Z;#_____)4A'!0AH(```
M`.F@_____R5,1P4(:"@```#ID/____\E4$<%"&@P````Z8#_____)51'!0AH
M.````.EP_____R581P4(:$````#I8/____\E7$<%"&A(````Z5#_____)6!'
M!0AH4````.E`_____R5D1P4(:%@```#I,/____\E:$<%"&A@````Z2#_____
M)6Q'!0AH:````.D0_____R5P1P4(:'````#I`/____\E=$<%"&AX````Z?#^
M____)7A'!0AH@````.G@_O___R5\1P4(:(@```#IT/[___\E@$<%"&B0````
MZ<#^____)81'!0AHF````.FP_O___R6(1P4(:*````#IH/[___\EC$<%"&BH
M````Z9#^____)9!'!0AHL````.F`_O___R641P4(:+@```#I</[___\EF$<%
M"&C`````Z6#^____)9Q'!0AHR````.E0_O___R6@1P4(:-````#I0/[___\E
MI$<%"&C8````Z3#^____):A'!0AHX````.D@_O___R6L1P4(:.@```#I$/[_
M__\EL$<%"&CP````Z0#^____);1'!0AH^````.GP_?___R6X1P4(:``!``#I
MX/W___\EO$<%"&@(`0``Z=#]____)<!'!0AH$`$``.G`_?___R7$1P4(:!@!
M``#IL/W___\ER$<%"&@@`0``Z:#]____)<Q'!0AH*`$``.F0_?___R701P4(
M:#`!``#I@/W___\EU$<%"&@X`0``Z7#]____)=A'!0AH0`$``.E@_?___R7<
M1P4(:$@!``#I4/W___\EX$<%"&A0`0``Z4#]____)>1'!0AH6`$``.DP_?__
M_R7H1P4(:&`!``#I(/W___\E[$<%"&AH`0``Z1#]____)?!'!0AH<`$``.D`
M_?___R7T1P4(:'@!``#I\/S___\E^$<%"&B``0``Z>#\____)?Q'!0AHB`$`
M`.G0_/___R4`2`4(:)`!``#IP/S___\E!$@%"&B8`0``Z;#\____)0A(!0AH
MH`$``.F@_/___R4,2`4(:*@!``#ID/S___\E$$@%"&BP`0``Z8#\____)11(
M!0AHN`$``.EP_/___R482`4(:,`!``#I8/S___\E'$@%"&C(`0``Z5#\____
M)2!(!0AHT`$``.E`_/___R4D2`4(:-@!``#I,/S___\E*$@%"&C@`0``Z2#\
M____)2Q(!0AHZ`$``.D0_/___R4P2`4(:/`!``#I`/S___\E-$@%"&CX`0``
MZ?#[____)3A(!0AH``(``.G@^____R4\2`4(:`@"``#IT/O___\E0$@%"&@0
M`@``Z<#[____)41(!0AH&`(``.FP^____R5(2`4(:"`"``#IH/O___\E3$@%
M"&@H`@``Z9#[____)5!(!0AH,`(``.F`^____R542`4(:#@"``#I</O___\E
M6$@%"&A``@``Z6#[____)5Q(!0AH2`(``.E0^____R5@2`4(:%`"``#I0/O_
M__\E9$@%"&A8`@``Z3#[____)6A(!0AH8`(``.D@^____R5L2`4(:&@"``#I
M$/O__P```````````````#'M7HGA@^3P4%12:&#7!`AH<-<$"%%6:#;4!`CH
M0_S___20D)"0D)"0D)"0D)"0D%6)Y5.#[`2`/;A(!0@`=4"+%;Q(!0BX*$8%
M""TD1@4(P?@"C5C_.=IS'XVV`````(U"`:.\2`4(_Q2%)$8%"(L5O$@%"#G:
M<N?&!;A(!0@!@\0$6UW#C78`C;PG`````%6)Y8/L"*$L1@4(A<!T$K@`````
MA<!T"<<$)"Q&!0C_T,G#D%6)Y8/L*,=%_*C8!`C'!"0`````Z+?^__^+`(D$
M).B=^___B<*+1?R)1"0,QT0D"&29!`C'1"0$LM@$"(D4).A<_O__R<-5B>53
M@>PT$```BT4,B87H[___BT40B87D[___9:$4````B47X,<#'1"0(_P\``(V%
M^.___XE$)`3'!"3.V`0(Z'7]__^)A?3O__^#O?3O__\`?AR+A?3O__^#Z`$/
MMH0%^.___X3`=0>#K?3O__\!@[WT[___`'YDBX7T[___B40D",=$)`0O````
MC87X[___B00DZ(']__^%P'1`BYWT[___QP0D`````.C;_?__BP")!"3HP?K_
M_XG"B5PD#(V%^.___XE$)`B+A>CO__^)1"0$B10DZ/_[___K-,<$)`````#H
MH?W__XL`B00DZ(?Z__^)PHN%Y.___XE$)`B+A>CO__^)1"0$B10DZ$GZ__^+
M1?AE,P44````=`7H2/S__X'$-!```%M=PU6)Y8/L*(-]"`!T":&@2`4(A<!U
M#,=%[`````#IH@```(M%"(E%].L$@T7T`8M5]`^V`H3`=`J+3?0/M@$\/77H
MBU7TBT4(B=$IP8E-\*&@2`4(B47XZU:+1?")1"0(BU4(B50D!(M-_(D,).B.
M_/__A<!U-8M%\`-%_`^V`#P]=2B+5?BAH$@%"(G1*<&)R,'X`HG"BT4,B1"+
M1?"#P`&+5?P!PHE5[.L9@T7X!(M-^(L)B4W\@WW\`'6<QT7L`````(M%[,G#
M58GE@^P8C47\B40D!(M%"(D$).@@____R<-5B>53@^PTBU4,#[8"/#UU!(-%
M#`&+30R)#"3H??K__XE%^(U%](E$)`2+10B)!"3HZ?[__XE%X(-]X`!T0HM%
MX(D$).A4^O__.T7X#X($`0``BU4,#[8"BTW@B`&+5>`/M@*$P`^5P(-%X`&#
M10P!A,!UWL=%W`````#IJ`$``(L-H$@%"(E-Z,=%Y`````#K"(-%Z`2#1>0!
MBU7HBP*%P'7OH<!(!0B%P'0UBT7D@\`"P>`"BQ6@2`4(B40D!(D4).C&]___
MHZ!(!0BAH$@%"(7`=6/'1=S_____Z4<!``#'!<!(!0@!````BT7D@\`"P>`"
MB00DZ$'Z__^)1>B#?>@`=0S'1=S_____Z1<!``"+1>3!X`*+%:!(!0B)1"0(
MB50D!(M-Z(D,).B-^O__BT7HHZ!(!0B+%:!(!0B+1>2#P`'!X`*-!`+'````
M``"+1>2)1?2+50B)5>#K!(-%X`&+3>`/M@&$P'0*BU7@#[8"/#UUZ(L5H$@%
M"(M%],'@`HT<`HM5X(M%"(G1*<&)R`-%^(/``HD$).B>^?__B0.+`X7`=0G'
M1=S_____ZWB+%:!(!0B+1?3!X`*-!`*+`(E%X.L$@T7@`8M%"`^V`(M5X(@"
MBTW@#[8!A,`/E<"#10@!@_`!A,!U"HM5X`^V`CP]==&+3>#&`3V#1>`!BU4,
M#[8"BTW@B`&+5>`/M@*$P`^5P(-%X`&#10P!A,!UWL=%W`````"+1=R#Q#1;
M7<-5B>6#["CK+8L5H$@%"(M%_,'@`@'"B57LBT7L@\`$BP"+5>R)`HM5[(L"
MA<!T!H-%[`3KY(U%_(E$)`2+10B)!"3HIOS__X7`=;W)PU6)Y8'L*"```&6A
M%````(E%_#'`QX7TW___`````.B,]?__QT0D#.'8!`B)1"0(QT0D!.78!`B-
MA?OO__^)!"3H2O7__XF%\-___X.]\-___P!Y#\>%[-___P````#II````,=$
M)`@`$```C87ZW___B40D!(V%^^___XD$).BL^/__B87PW___@[WPW___`'D,
MQX7LW___`````.MIBX7PW___@\`!B00DZ!#X__^)A?3?__^#O?3?__\`=0S'
MA>S?__\`````ZSV+A?#?__^)1"0(C87ZW___B40D!(N%]-___XD$).@3]___
MBX7PW___`X7TW___Q@``BY7TW___B97LW___BX7LW___BU7\93,5%````'0%
MZ,'W___)PU6)Y8/L".C5_O__R<-5B>6![$@0``"+10B)A=SO__^+10R)A=CO
M__]EH10```")1?PQP,<$)/'8!`CH"?S__XF%[.___Z%X2`4(B40D!(N%W.__
M_XD$).@S]___A<!T)XN%W.___XE$)`3'!"3ZV`0(Z.S[__^+E=SO__^)E=3O
M___I/@(``(N%W.___XD$).AJ]O__B87T[___H7Q(!0B)1"0$BX78[___B00D
MZ"WW__^)A?CO___IV0$``(N%^.___P^V`(3`=0K'A?CO__\'V00(@[WL[___
M`'0\BX7X[___B40D!(N%[.___XD$).@*^/__A<!U(*%\2`4(B40D!,<$)```
M``#HT?;__XF%^.___^E]`0``BX7X[___B00DZ-CU__^)A?#O___K%H.M\.__
M_P&+A?#O__\#A?CO___&``"+A?#O__^#Z`$#A?CO__\/MA"A>$@%"`^V`#C"
M=,R+A?#O__^#P`$#A?3O__\]_P\``'XGBX7<[___B40D!,<$)/K8!`CHT_K_
M_XN%W.___XF%U.___^DE`0``BQ5X2`4(BX7<[___B40D$(E4)`R+A?CO__^)
M1"0(QT0D!`G9!`B-A?SO__^)!"3HF_+__\<$)`````#H__;__XL`B00DZ.7S
M__^)!"3H#?;__XE$)`2-A?SO__^)!"3H]S(``(7`=7/'!"0`````Z,OV__^+
M`(D$).BQ\___B00DZ-GU__^+0!`E`/```#T`@```=4;'1"0$`0```(V%_.__
M_XD$).CT\___A<!U+(V%_.___XE$)`3'!"3ZV`0(Z/WY__^-A?SO__^)!"3H
M7/;__XF%U.___^M*H7Q(!0B)1"0$QP0D`````.A/]?__B87X[___@[WX[___
M``^%&O[__XN%W.___XE$)`3'!"3ZV`0(Z*GY__^+E=SO__^)E=3O__^+A=3O
M__^+5?QE,Q44````=`7HX_3__\G#58GE@^P0BT4(B47\BT4(B47XZQ^+1?@/
MMA"A>$@%"`^V`#C"=0F+1?B#P`&)1?R#1?@!BT7X#[8`A,!UUXM%_,G#58GE
M@^P8@WT(`'0*BT4(#[8`A,!U%,<$)`?9!`CHC?7__XE%^.D!`0``BT4(B00D
MZ*KS__^#Z`&+50@!PHE5_.L$@VW\`8M-_#M-"'89BU7\#[8"BQ5X2`4(#[82
M.-!TX>L$@VW\`8M-_#M-"'83BU7\#[8"BQ5X2`4(#[82.-!UX8M-_#M-"'4V
MBU7\#[8"BQ5X2`4(#[82.-!U$<<$)`?9!`CH!O7__XE%^.M]H7A(!0B)!"3H
M]/3__XE%^.MK@VW\`8M-_#M-"'83BU7\#[8"BQ5X2`4(#[82.-!TX8M5_(M%
M"(G1*<&)R(/``CT`$```=@G'1?@`````ZRV+5?R+10B)T2G!B<B#P`&)1"0(
MBT4(B40D!,<$).!(!0CH^_#__\=%^.!(!0B+1?C)PU6)Y8/L2&6A%````(E%
M_#'`H;S9!`B)1=JAP-D$"(E%WJ'$V00(B47BH<C9!`B)1>:AS-D$"(E%ZJ'0
MV00(B47NH=39!`B)1?*AV-D$"(E%]@^W!=S9!`AFB47ZQP0D$-D$".C;^?__
MQP0D(-D$".C/^?__QP0D\=@$".C#^?__QP0D+-D$".BW^?__QP0D-MD$".BK
M^?__QP0D0-D$".B?^?__QP0D^M@$".B3^?__QP0D2MD$".B'^?__QP0D4]D$
M".A[^?__QP0D7MD$".@D]___B474@WW4`'03BT74B40D!,<$)#;9!`CH(O?_
M_\<$)&_9!`CH_/;__XE%U(-]U`!T$XM%U(E$)`3'!"2!V00(Z/KV___'!"2,
MV00(Z-3V__^)1=2#?=0`=!6+1=2)1"0$QP0D\=@$".C2]O__ZVC'!"2<V00(
MZ*KV__^)1=2#?=0`=!6+1=2)1"0$QP0D+-D$".BH]O__ZSZ-1=J#P!&)1=3'
M1"0("@```,=$)`2MV00(BT74B00DZ)_R__^%P'46BT74@\`*B40D!,<$)"S9
M!`CH:/;__\=$)`2XV00(QP0D$-D$".A4]O__BT7\93,%%````'0%Z*#Q___)
MPU6)Y8/L&*&`2`4(@_C_=4''!"0LV00(Z`OV__^)1?R#??P`=!V+1?P/M@"$
MP'03BT7\#[8`/#!T"<=%[`$```#K!\=%[`````"+1>RC@$@%"*&`2`4(R<-5
MB>53@>QP`0``BT4(@\`<B47TQT7X`````.M$BT7TBP")1?"#1?0$BTWXBT7P
MB<+!XAB+1?#!X`@E``#_``G"BT7PP>@()0#_```)PHM%\,'H&`G0B82-F/[_
M_X-%^`&#??@/?K;'1?@0````ZU^+3?B+1?B#Z`.+E(68_O__BT7X@^@(BX2%
MF/[__S'"BT7X@^@.BX2%F/[__S'"BT7X@^@0BX2%F/[__S'0B82-F/[__XM5
M^(M%^(N$A9C^___!R!^)A)68_O__@T7X`8-]^$]^FXM%"(L`B47LBT4(BT`$
MB47HBT4(BT`(B47DBT4(BT`,B47@BT4(BT`0B47<C868_O__B478BT7LB<'!
MR1N+5>2+1>@APHM%Z/?0(T7@"="-!`&)P@-5W(M%V(L`C00"!9EY@EJ)1?"#
M1=@$P4WH`HM%\(G!P<D;BU7HBT7L(<*+1>SWT"-%Y`G0C00!B<(#5>"+1=B+
M`(T$`@69>8):B47<@T78!,%-[`*+1=R)P<')&XM5[(M%\"'"BT7P]]`C1>@)
MT(T$`8G"`U7DBT78BP"-!`(%F7F"6HE%X(-%V`3!3?`"BT7@B<'!R1N+5?"+
M1=PAPHM%W/?0(T7L"="-!`&)P@-5Z(M%V(L`C00"!9EY@EJ)1>2#1=@$P4W<
M`HM%Y(G!P<D;BU7<BT7@(<*+1>#WT"-%\`G0C00!B<(#5>R+1=B+`(T$`@69
M>8):B47H@T78!,%-X`*+1>B)P<')&XM5X(M%Y"'"BT7D]]`C1=P)T(T$`8G"
M`U7PBT78BP"-!`(%F7F"6HE%[(-%V`3!3>0"BT7LB<'!R1N+5>2+1>@APHM%
MZ/?0(T7@"="-!`&)P@-5W(M%V(L`C00"!9EY@EJ)1?"#1=@$P4WH`HM%\(G!
MP<D;BU7HBT7L(<*+1>SWT"-%Y`G0C00!B<(#5>"+1=B+`(T$`@69>8):B47<
M@T78!,%-[`*+1=R)P<')&XM5[(M%\"'"BT7P]]`C1>@)T(T$`8G"`U7DBT78
MBP"-!`(%F7F"6HE%X(-%V`3!3?`"BT7@B<'!R1N+5?"+1=PAPHM%W/?0(T7L
M"="-!`&)P@-5Z(M%V(L`C00"!9EY@EJ)1>2#1=@$P4W<`HM%Y(G!P<D;BU7<
MBT7@(<*+1>#WT"-%\`G0C00!B<(#5>R+1=B+`(T$`@69>8):B47H@T78!,%-
MX`*+1>B)P<')&XM5X(M%Y"'"BT7D]]`C1=P)T(T$`8G"`U7PBT78BP"-!`(%
MF7F"6HE%[(-%V`3!3>0"BT7LB<'!R1N+5>2+1>@APHM%Z/?0(T7@"="-!`&)
MP@-5W(M%V(L`C00"!9EY@EJ)1?"#1=@$P4WH`HM%\(G!P<D;BU7HBT7L(<*+
M1>SWT"-%Y`G0C00!B<(#5>"+1=B+`(T$`@69>8):B47<@T78!,%-[`*+1=R)
MP<')&XM5[(M%\"'"BT7P]]`C1>@)T(T$`8G"`U7DBT78BP"-!`(%F7F"6HE%
MX(-%V`3!3?`"BT7@B<'!R1N+5?"+1=PAPHM%W/?0(T7L"="-!`&)P@-5Z(M%
MV(L`C00"!9EY@EJ)1>2#1=@$P4W<`HM%Y(G!P<D;BU7<BT7@(<*+1>#WT"-%
M\`G0C00!B<(#5>R+1=B+`(T$`@69>8):B47H@T78!,%-X`*+1>B)P<')&XM5
MX(M%Y"'"BT7D]]`C1=P)T(T$`8G"`U7PBT78BP"-!`(%F7F"6HE%[(-%V`3!
M3>0"BT7LB<'!R1N+5>2+1>@APHM%Z/?0(T7@"="-!`&)P@-5W(M%V(L`C00"
M!9EY@EJ)1?"#1=@$P4WH`HM%\(G!P<D;BU7HBT7L(<*+1>SWT"-%Y`G0C00!
MB<(#5>"+1=B+`(T$`@69>8):B47<@T78!,%-[`*+1=R)P<')&XM5[(M%\#'0
M,T7HC00!B<(#5>2+1=B+`(T$`@6AZ]ENB47@@T78!,%-\`*+1>")P<')&XM5
M\(M%W#'0,T7LC00!B<(#5>B+1=B+`(T$`@6AZ]ENB47D@T78!,%-W`*+1>2)
MP<')&XM5W(M%X#'0,T7PC00!B<(#5>R+1=B+`(T$`@6AZ]ENB47H@T78!,%-
MX`*+1>B)P<')&XM5X(M%Y#'0,T7<C00!B<(#5?"+1=B+`(T$`@6AZ]ENB47L
M@T78!,%-Y`*+1>R)P<')&XM5Y(M%Z#'0,T7@C00!B<(#5=R+1=B+`(T$`@6A
MZ]ENB47P@T78!,%-Z`*+1?")P<')&XM5Z(M%[#'0,T7DC00!B<(#5>"+1=B+
M`(T$`@6AZ]ENB47<@T78!,%-[`*+1=R)P<')&XM5[(M%\#'0,T7HC00!B<(#
M5>2+1=B+`(T$`@6AZ]ENB47@@T78!,%-\`*+1>")P<')&XM5\(M%W#'0,T7L
MC00!B<(#5>B+1=B+`(T$`@6AZ]ENB47D@T78!,%-W`*+1>2)P<')&XM5W(M%
MX#'0,T7PC00!B<(#5>R+1=B+`(T$`@6AZ]ENB47H@T78!,%-X`*+1>B)P<')
M&XM5X(M%Y#'0,T7<C00!B<(#5?"+1=B+`(T$`@6AZ]ENB47L@T78!,%-Y`*+
M1>R)P<')&XM5Y(M%Z#'0,T7@C00!B<(#5=R+1=B+`(T$`@6AZ]ENB47P@T78
M!,%-Z`*+1?")P<')&XM5Z(M%[#'0,T7DC00!B<(#5>"+1=B+`(T$`@6AZ]EN
MB47<@T78!,%-[`*+1=R)P<')&XM5[(M%\#'0,T7HC00!B<(#5>2+1=B+`(T$
M`@6AZ]ENB47@@T78!,%-\`*+1>")P<')&XM5\(M%W#'0,T7LC00!B<(#5>B+
M1=B+`(T$`@6AZ]ENB47D@T78!,%-W`*+1>2)P<')&XM5W(M%X#'0,T7PC00!
MB<(#5>R+1=B+`(T$`@6AZ]ENB47H@T78!,%-X`*+1>B)P<')&XM5X(M%Y#'0
M,T7<C00!B<(#5?"+1=B+`(T$`@6AZ]ENB47L@T78!,%-Y`*+1>R)P<')&XM5
MY(M%Z#'0,T7@C00!B<(#5=R+1=B+`(T$`@6AZ]ENB47P@T78!,%-Z`*+1?")
MP<')&XM5Z(M%[#'0,T7DC00!B<(#5>"+1=B+`(T$`@6AZ]ENB47<@T78!,%-
M[`*+1=R)P<')&XM5[(M%\#'0,T7HC00!B<(#5>2+1=B+`(T$`@6AZ]ENB47@
M@T78!,%-\`*+1>")P<')&XM5\(M%W#'0,T7LC00!B<(#5>B+1=B+`(T$`@6A
MZ]ENB47D@T78!,%-W`*+1>2)P\'+&XM5\(M%W`G0B<$C3>"+5?"+1=PAT`G(
MC00#B<(#5>R+1=B+`(T$`BTD0^1PB47H@T78!,%-X`*+1>B)P\'+&XM5W(M%
MX`G0B<$C3>2+5=R+1>`AT`G(C00#B<(#5?"+1=B+`(T$`BTD0^1PB47L@T78
M!,%-Y`*+1>R)P\'+&XM5X(M%Y`G0B<$C3>B+5>"+1>0AT`G(C00#B<(#5=R+
M1=B+`(T$`BTD0^1PB47P@T78!,%-Z`*+1?")P\'+&XM5Y(M%Z`G0B<$C3>R+
M5>2+1>@AT`G(C00#B<(#5>"+1=B+`(T$`BTD0^1PB47<@T78!,%-[`*+1=R)
MP\'+&XM5Z(M%[`G0B<$C3?"+5>B+1>PAT`G(C00#B<(#5>2+1=B+`(T$`BTD
M0^1PB47@@T78!,%-\`*+1>")P\'+&XM5[(M%\`G0B<$C3=R+5>R+1?`AT`G(
MC00#B<(#5>B+1=B+`(T$`BTD0^1PB47D@T78!,%-W`*+1>2)P\'+&XM5\(M%
MW`G0B<$C3>"+5?"+1=PAT`G(C00#B<(#5>R+1=B+`(T$`BTD0^1PB47H@T78
M!,%-X`*+1>B)P\'+&XM5W(M%X`G0B<$C3>2+5=R+1>`AT`G(C00#B<(#5?"+
M1=B+`(T$`BTD0^1PB47L@T78!,%-Y`*+1>R)P\'+&XM5X(M%Y`G0B<$C3>B+
M5>"+1>0AT`G(C00#B<(#5=R+1=B+`(T$`BTD0^1PB47P@T78!,%-Z`*+1?")
MP\'+&XM5Y(M%Z`G0B<$C3>R+5>2+1>@AT`G(C00#B<(#5>"+1=B+`(T$`BTD
M0^1PB47<@T78!,%-[`*+1=R)P\'+&XM5Z(M%[`G0B<$C3?"+5>B+1>PAT`G(
MC00#B<(#5>2+1=B+`(T$`BTD0^1PB47@@T78!,%-\`*+1>")P\'+&XM5[(M%
M\`G0B<$C3=R+5>R+1?`AT`G(C00#B<(#5>B+1=B+`(T$`BTD0^1PB47D@T78
M!,%-W`*+1>2)P\'+&XM5\(M%W`G0B<$C3>"+5?"+1=PAT`G(C00#B<(#5>R+
M1=B+`(T$`BTD0^1PB47H@T78!,%-X`*+1>B)P\'+&XM5W(M%X`G0B<$C3>2+
M5=R+1>`AT`G(C00#B<(#5?"+1=B+`(T$`BTD0^1PB47L@T78!,%-Y`*+1>R)
MP\'+&XM5X(M%Y`G0B<$C3>B+5>"+1>0AT`G(C00#B<(#5=R+1=B+`(T$`BTD
M0^1PB47P@T78!,%-Z`*+1?")P\'+&XM5Y(M%Z`G0B<$C3>R+5>2+1>@AT`G(
MC00#B<(#5>"+1=B+`(T$`BTD0^1PB47<@T78!,%-[`*+1=R)P\'+&XM5Z(M%
M[`G0B<$C3?"+5>B+1>PAT`G(C00#B<(#5>2+1=B+`(T$`BTD0^1PB47@@T78
M!,%-\`*+1>")P\'+&XM5[(M%\`G0B<$C3=R+5>R+1?`AT`G(C00#B<(#5>B+
M1=B+`(T$`BTD0^1PB47D@T78!,%-W`*+1>2)P\'+&XM5\(M%W`G0B<$C3>"+
M5?"+1=PAT`G(C00#B<(#5>R+1=B+`(T$`BTD0^1PB47H@T78!,%-X`*+1>B)
MP\'+&XM5W(M%X`G0B<$C3>2+5=R+1>`AT`G(C00#B<(#5?"+1=B+`(T$`BTD
M0^1PB47L@T78!,%-Y`*+1>R)P<')&XM5Y(M%Z#'0,T7@C00!B<(#5=R+1=B+
M`(T$`BTJ/ITUB47P@T78!,%-Z`*+1?")P<')&XM5Z(M%[#'0,T7DC00!B<(#
M5>"+1=B+`(T$`BTJ/ITUB47<@T78!,%-[`*+1=R)P<')&XM5[(M%\#'0,T7H
MC00!B<(#5>2+1=B+`(T$`BTJ/ITUB47@@T78!,%-\`*+1>")P<')&XM5\(M%
MW#'0,T7LC00!B<(#5>B+1=B+`(T$`BTJ/ITUB47D@T78!,%-W`*+1>2)P<')
M&XM5W(M%X#'0,T7PC00!B<(#5>R+1=B+`(T$`BTJ/ITUB47H@T78!,%-X`*+
M1>B)P<')&XM5X(M%Y#'0,T7<C00!B<(#5?"+1=B+`(T$`BTJ/ITUB47L@T78
M!,%-Y`*+1>R)P<')&XM5Y(M%Z#'0,T7@C00!B<(#5=R+1=B+`(T$`BTJ/ITU
MB47P@T78!,%-Z`*+1?")P<')&XM5Z(M%[#'0,T7DC00!B<(#5>"+1=B+`(T$
M`BTJ/ITUB47<@T78!,%-[`*+1=R)P<')&XM5[(M%\#'0,T7HC00!B<(#5>2+
M1=B+`(T$`BTJ/ITUB47@@T78!,%-\`*+1>")P<')&XM5\(M%W#'0,T7LC00!
MB<(#5>B+1=B+`(T$`BTJ/ITUB47D@T78!,%-W`*+1>2)P<')&XM5W(M%X#'0
M,T7PC00!B<(#5>R+1=B+`(T$`BTJ/ITUB47H@T78!,%-X`*+1>B)P<')&XM5
MX(M%Y#'0,T7<C00!B<(#5?"+1=B+`(T$`BTJ/ITUB47L@T78!,%-Y`*+1>R)
MP<')&XM5Y(M%Z#'0,T7@C00!B<(#5=R+1=B+`(T$`BTJ/ITUB47P@T78!,%-
MZ`*+1?")P<')&XM5Z(M%[#'0,T7DC00!B<(#5>"+1=B+`(T$`BTJ/ITUB47<
M@T78!,%-[`*+1=R)P<')&XM5[(M%\#'0,T7HC00!B<(#5>2+1=B+`(T$`BTJ
M/ITUB47@@T78!,%-\`*+1>")P<')&XM5\(M%W#'0,T7LC00!B<(#5>B+1=B+
M`(T$`BTJ/ITUB47D@T78!,%-W`*+1>2)P<')&XM5W(M%X#'0,T7PC00!B<(#
M5>R+1=B+`(T$`BTJ/ITUB47H@T78!,%-X`*+1>B)P<')&XM5X(M%Y#'0,T7<
MC00!B<(#5?"+1=B+`(T$`BTJ/ITUB47L@T78!,%-Y`*+1>R)P<')&XM5Y(M%
MZ#'0,T7@C00!B<(#5=R+1=B+`(T$`BTJ/ITUB47P@T78!,%-Z`*+1?")P<')
M&XM5Z(M%[#'0,T7DC00!B<(#5>"+1=B+`(T$`BTJ/ITUB47<@T78!,%-[`*+
M10B+`(G"`U7<BT4(B1"+10B+0`2)P@-5\(M%"(E0!(M%"(M`"(G"`U7LBT4(
MB5`(BT4(BT`,B<(#5>B+10B)4`R+10B+0!")P@-5Y(M%"(E0$('$<`$``%M=
MPU6)Y8M%",<``2-%9XM%",=`!(FKS>^+10C'0`C^W+J8BT4(QT`,=E0R$(M%
M",=`$/#ATL.+10C'0!0`````BT4(QT`8`````(M%",=`7`````!=PU6)Y8/L
M*(M%"(M0%(M%$,'@`XT$`HE%^(M%"(M`%#M%^'8/BT4(BT`8C5`!BT4(B5`8
MBU4(BT7XB4(4BT4(BU`8BT40P>@=`<*+10B)4!B+10B+0%R%P`^$IP```(M%
M"(M07+A`````*=")1?R+1?P[11!^!HM%$(E%_(M-_(M%"(U0'(M%"(M`7`'"
MB4PD"(M%#(E$)`2)%"3HHMS__XM%_"E%$(M%_`%%#(M%"(M`7(G"`U7\BT4(
MB5!<BT4(BT!<@_A`=6B+10B)!"3H">S__^LPBT4(C5`<QT0D"$````"+10R)
M1"0$B10DZ%#<__^#10Q`@VT00(M%"(D$).C7Z___@WT0/W_*BU40BT4(C4@<
MB50D"(M%#(E$)`2)#"3H&]S__XM5"(M%$(E"7,G#58GE@^P$BT4,B00DZ)GK
M__^+10R+`,'H&(G"BT4(B!"+10B-4`&+10R+`,'H$(@"BT4(C5`"BT4,BP#!
MZ`B(`HM%"(U0`XM%#(L`B`*+10B-4`2+10R+0`3!Z!B(`HM%"(U0!8M%#(M`
M!,'H$(@"BT4(C5`&BT4,BT`$P>@(B`*+10B-4`>+10R+0`2(`HM%"(U0"(M%
M#(M`",'H&(@"BT4(C5`)BT4,BT`(P>@0B`*+10B-4`J+10R+0`C!Z`B(`HM%
M"(U0"XM%#(M`"(@"BT4(C5`,BT4,BT`,P>@8B`*+10B-4`V+10R+0`S!Z!"(
M`HM%"(U0#HM%#(M`#,'H"(@"BT4(C5`/BT4,BT`,B`*+10B-4!"+10R+0!#!
MZ!B(`HM%"(U0$8M%#(M`$,'H$(@"BT4(C5`2BT4,BT`0P>@(B`*+10B-4!.+
M10R+0!"(`LG#58GE@^PHBT4,BT`4B47XBT4,BT`8B47TBT7XP>@#@^`_B47\
MBT4,C5`<BT7\C00"Q@"`@T7\`8-]_#A^5;A`````*T7\B<&+10R-4!R+1?R-
M!`*)3"0(QT0D!`````")!"3H%MG__XM%#(D$).CEZ?__BT4,@\`<QT0D"#@`
M``#'1"0$`````(D$).CMV/__ZRJX.````"M%_(G!BT4,C5`<BT7\C00"B4PD
M",=$)`0`````B00DZ,'8__^+1?3!Z!B)PHM%#(A05(M%],'H$(G"BT4,B%!5
MBT7TP>@(B<*+10R(4%:+1?2)PHM%#(A05XM%^,'H&(G"BT4,B%!8BT7XP>@0
MB<*+10R(4%F+1?C!Z`B)PHM%#(A06HM%^(G"BT4,B%!;BT4,B40D!(M%"(D$
M).AU_?__R<-5B>6#[!C'1?P`````QT7X`````.C*V?__B47T@WWT`'06BT7T
MB00DZ);9__^)1?B+1?B+`(E%_(M%_,G#58GE4X/L1,=%^`````#'1?0`````
MQT74WMD$",=%V.[9!`C'1=SVV00(QT7@`]H$",=%Y`C:!`C'1>@:V@0(QT7L
M`````,=%\`````#IQ````(M%^(D$).A2WO__B47T@WWT`'0*BT7T#[8`A,!U
M%XM%"(E$)`2+1?B)!"3H1][__^F+````BT4(B40D!(M%](D$).A=V?__A<!U
M=8M%"(D$).B^V/__B<.A?$@%"(D$).BOV/__`<.+1?2)!"3HHMC__XT$`X/`
M`HD$).@TV?__B47LBQ5\2`4(BT7TB40D$(E4)`R+10B)1"0(QT0D!`G9!`B+
M1>R)!"3HUM7__XM%[(E$)`2+1?B)!"3HM]W__X-%\`&+1?"+1(74B47XBT7X
M#[8`A,`/A23___^#Q$1;7<-5B>53@>PT@0``BT4(B87H?O__9:$4````B47X
M,<#'A4Q___\`````QX5(?___`````,>%1'___P````#'A01___\;V@0(QX4(
M?___(]H$",>%#'___P?9!`C'A1!___\:V@0(QX7L?O__@=D$",>%\'[__RC:
M!`C'A?1^__\OV@0(QX7X?O__-]H$",>%_'[__SS:!`C'A0!___\:V@0(QX44
M?___0-H$",>%&'___T7:!`C'A1Q___\:V@0(QX5`?___3MH$",>%/'___QK:
M!`C'A3A___\`````QX4T?___`````,>%,'___P````#'A2!___\`````QP0D
M\=@$".AUW/__B85$?___@[U$?___`'0TBX5$?___#[8`A,!T)XN%1'___XD$
M).B<_?__BX5$?___B00DZ,38__^)A>1^___I"`<``.A!_?__B84T?___@[TT
M?___`'5MQX54?___`````.LXBX5(?___B00DZ`3<__^)A41___^#O41___\`
M=!2+A41___^)!"3H;MC__XF%-'___X.%5'___P&#O31___\`=2"+A51___^+
MA(44?___B85(?___BX5(?___#[8`A,!UGX.]-'___P!U#,>%-'___U/:!`CK
M4(N%-'___XF%4'___^LUZ,#5__^+$(N%4'___P^V``^^P`'`C00"#[<`#[?`
M@^`(A<!U"8N%4'___\8`7X.%4'___P&+A5!___\/M@"$P'6^QX54?___````
M`.GH````BX5(?___B00DZ"_;__^)A41___^#O41___\`#X3`````QP0D````
M`.BGU___BP")!"3HC=3__XD$).BUUO__B40D!(N%1'___XD$).C?$P``A<`/
MA8@```#'!"0`````Z&_7__^+`(D$).A5U/__B00DZ'W6__^+0!`E`/```#T`
M0```="W'!"0`````Z$+7__^+`(D$).@HU/__B00DZ%#6__^+0!`E`/```#T`
MH```=2['1"0$`@```(N%1'___XD$).AKU/__A<!U%(N%1'___XD$).CIUO__
MB85,?___@X54?___`8.]3'___P!U)(N%5'___XN$A>Q^__^)A4A___^+A4A_
M__\/M@"$P`^%Z_[__\>%5'___P````#IQP```,<$)`````#HI-;__XL`B00D
MZ(K3__^)!"3HLM7__XE$)`2+A41___^)!"3HW!(``(7`#X6(````QP0D````
M`.ALUO__BP")!"3H4M/__XD$).AZU?__BT`0)0#P```]`$```'0MQP0D````
M`.@_UO__BP")!"3H)=/__XD$).A-U?__BT`0)0#P```]`*```'4NQT0D!`(`
M``"+A41___^)!"3H:-/__X7`=12+A41___^)!"3HYM7__XF%3'___X.%5'__
M_P&#O4Q___\`=22+A51___^+A(4$?___B85$?___BX5$?___#[8`A,`/A0S_
M__^+A4Q___^)!"3HSM/__XG#BX5`?___B00DZ+[3__\!PXN%-'___XD$).BN
MT___`<.+A3Q___^)!"3HGM/__XT$`P4`!```B84@?___BX4@?___B00DZ"+4
M__^)A3!___^+%7A(!0B+A31___^)1"04BX5`?___B40D$(E4)`R+A4Q___^)
M1"0(QT0D!%K:!`B+A3!___^)!"3HKM#__\=$)`3M`0``BX4P?___B00DZ,C0
M___'!"0#V@0(Z&78__^)A41___^+A41___^)!"3HV-3__XG"BX7H?O__BP")
M5"0$B00DZ`#<__^)A3A___^#O3A___\`=0Z+A>A^__^+`(F%.'___^CRX?__
MA<`/A60"``#'1"0$`````(N%.'___XD$).A"U/__B84L?___@[TL?___``^$
M.P(``,=$)`P"````QT0D!.[____'1"0(_____XN%+'___XD$).C9T/__QT0D
M"`8```"-A5A___^)1"0$BX4L?___B00DZ#G1__\/MH58?___A,`/A=0````/
MMH59?___/$,/A<4````/MH5:?___/$$/A;8````/MH5;?___/$,/A:<````/
MMH5<?___/$@/A9@````/MH5=?___/$4/A8D```#'1"0,`@```,=$)`3&____
MQT0D"/____^+A2Q___^)!"3H.=#__\=$)`@I````C858?___B40D!(N%+'__
M_XD$).B9T/__BQ5X2`4(BX4\?___B40D%(V%6'___XE$)!")5"0,BX4P?___
MB40D",=$)`1CV@0(BX4P?___B00DZ.O.___I90$``(V%6/___XD$).BS\___
MZR*+A2A___^)1"0(C858?___B40D!(V%6/___XD$).CC\___QT0D"`"```"-
MA5A___^)1"0$BX4L?___B00DZ`30__^)A2A___^#O2A___\`?Z^+A2Q___^)
M!"3H=]'__XV%6/___XE$)`2-1>2)!"3H%?;__\>%)'___P````#K.(N%)'__
M_P^V1`7D#[;(BX4D?___`<")PHU%NP'0B4PD",=$)`1RV@0(B00DZ"7.__^#
MA21___\!@[TD?___$WZ_QD7C`(L5>$@%"(N%/'___XE$)!2-1;N)1"00B50D
M#(N%,'___XE$)`C'1"0$8]H$"(N%,'___XD$).C6S?__ZU/'1"0$N-D$",<$
M)"S9!`CHL]7__^C;S?__B<*+#7A(!0B+A3Q___^)1"04B50D$(E,)`R+A3!_
M__^)1"0(QT0D!'?:!`B+A3!___^)!"3H@<W__XN%,'___XE$)`3'!"3QV`0(
MZ%[5__^+A3!___^)!"3HA_;__XN5,'___XF5Y'[__XN%Y'[__XM5^&4S%10`
M``!T!>B*T/__@<0T@0``6UW#58GE4X'LA````,=%\`````"+10B)!"3H!<__
M_XE%^(-]^``/A"D!``#I\````(M%](/`$\=$)`0'V00(B00DZ'W1__^%P`^$
MT@```(M%](/`$\=$)`2%V@0(B00DZ%_1__^%P`^$M````(M%"(D$).A,S___
MB<.+1?2#P!.)!"3H/,___XT$`X/``HE%[(M%[(D$).C(S___B47PBT7T@\`3
MB40D#(M%"(E$)`C'1"0$B-H$"(M%\(D$).AQS/__C46,B40D!(M%\(D$).CK
M#```@_C_="J+19PE`/```#T`0```=1N#?0P`=!7'1"0$`0```(M%\(D$).@!
M____ZPN+1?")!"3HQ<[__XM%\(D$).BZS?__QT7P`````(M%^(D$).AHSO__
MB47T@WWT``^%^/[__XM%^(D$).C@SO__@WT(`'0+BT4(B00DZ#_/__^!Q(0`
M``!;7<-5B>6#[!B+10B)!"3H=MK__XE%_(M%_(D$).@FVO__B47XZ&'=__^%
MP'1.@WT(`'1(BT4(#[8`A,!T/L=$)`1.V@0(BT7XB00DZ*C.__\[1?AU)L=$
M)`0!````BT4(B00DZ#_^___'1"0$`````(M%_(D$).@L_O__R<-5B>53@^P4
MQP0D`````.BXS___BP")!"3HGLS__XD$).A&R___BP"+6`3'!"0`````Z)7/
M__^+`(D$).A[S/__B00DZ,/+__\/M@"(0QC'!"0`````Z''/__^+`(D$).A7
MS/__B00DZ/_*__^+`(M8!,<$)`````#H3L___XL`B00DZ#3,__^)!"3HC,O_
M_XL`#[=`$&8E_P%FB4,:QP0D`````.@BS___BP")!"3H",S__XD$).BPRO__
MBP"+6`3'!"0`````Z/_.__^+`(D$).CER___QT0D"`````#'1"0$&MH$"(D$
M).A=SO__B4,<QP0D`````.C.SO__BP")!"3HM,O__XD$).A<RO__BP"+6`3'
M!"0`````Z*O.__^+`(D$).B1R___B00DZ+G*__^+`(E#(,<$)`````#HB,[_
M_XL`B00DZ&[+__^)!"3H%LK__XL`BT`$B47TQP0D`````.ABSO__BP")!"3H
M2,O__XD$).A@S?__BP"%P'0HQP0D`````.@^SO__BP")!"3H),O__XD$).@\
MS?__BP"+0&R)1?CK!\=%^`````"+5?B+1?2)4"3'!"0`````Z`;.__^+`(D$
M).CLRO__B00DZ)3)__^+`(M`!,=`*`````#'!"0`````Z-S-__^+`(D$).C"
MRO__B00DZ&K)__^+`(M`!,=`+`````#'!"0`````Z++-__^+`(D$).B8RO__
MB00DZ$#)__^+`(M8!,<$)`````#HC\W__XL`B00DZ'7*__^)!"3H/<W__XL`
MB4,P@\046UW#58GE@^P8QP0D`````.A@S?__BP")!"3H1LK__\=$)`3_____
MB00DZ(;*___'!"0`````Z#K-__^+`(D$).@@RO__QT0D"`````#'1"0$Z<L$
M"(D$).AHS?__R<-5B>564X/L0,=%X`````#'!"0`````Z/O,__^+`(D$).CA
MR?__B00DZ%G*___&``''!"00V00(Z$/0__^)1=R#?=P`=!>+1=P/M@`\,74-
MBT7<@\`!#[8`A,!T!>@FV/__QP0D`````.BIS/__BP")!"3HC\G__\=$)`P+
M````QT0D"`$```#'1"0$CMH$"(D$).@OR?__B47T@WWT``^$/@$``(M%](M`
M#(M`&(E%\,=%Y`$```#IR@```(M%Y(U8_\<$)`````#H2,S__XL`B00DZ"[)
M__^)PL=$)`P`````B5PD"(M%\(E$)`2)%"3HD<K__XE%[(-][``/A)(```"+
M1>R+`(M`""4`!```A<!T#8M%[(L`BT`,B47(ZSJ+1>R+&,<$)`````#HY<O_
M_XL`B00DZ,O(___'1"0,`@```,=$)`@`````B5PD!(D$).@?S/__B47(BQ7L
M6`4(BT7DP>`"C00"BP"+5<B)5"0$B00DZ+S+__^%P'46@T7@`8-%Y`&AZ%@%
M"#E%Y`^,*/___Z'H6`4(@^@!.T7@=4''1>0!````ZR['!"0`````Z&#+__^+
M`(D$).A&R/__B<*+1?")1"0$B10DZ.7'__^)1>B#1>0!H>A8!0@Y1>1\R,<$
M)`````#H*,O__XL`B00DZ`[(___'1"0,!0```,=$)`@!````QT0D!)/:!`B)
M!"3HKL?__XE%](-]]`!T<(M%](M`#(L8QP0D`````.CARO__BP")!"3HQ\?_
M_\=$)`B5V@0(B5PD!(D$).B3Q___BT7TBT`,BP"+0`@E``!``(7`="J+1?2+
M0`R+&,<$)`````#HF\K__XL`B00DZ(''__^)7"0$B00DZ%7)___'!"0`````
MZ'G*__^+`(D$).A?Q___QT0D#`4```#'1"0(`0```,=$)`2:V@0(B00DZ/_&
M__^)1?2#??0`#X2&````QT78`````,<$)/K8!`CHF,W__XE%V(-]V`!T-8M%
M](M`#(L8QP0D`````.@2RO__BP")!"3H^,;__XG"BT78B40D"(E<)`2)%"3H
MP\;__^LUH>Q8!0B+,(M%](M`#(L8QP0D`````.C6R?__BP")!"3HO,;__XET
M)`B)7"0$B00DZ#++___'!"0`````Z+#)__^+`(D$).B6QO__B00DZ`['___&
M``#'!"0`````Z(_)__^+`(D$).AUQO__B00DZ*W)___'``````#'!"3QV`0(
MZ-3,__^CY%@%"*'D6`4(A<`/A18!``"A[%@%"(D$).@Z[___H^18!0BA[%@%
M"(E%S(M%](M`#(L`BT`()0`$``"%P'00BT7TBT`,BP"+0`R)1=#K/8M%](M`
M#(L8QP0D`````.@'R?__BP")!"3H[<7__\=$)`P"````QT0D"`````")7"0$
MB00DZ$')__^)1="+5<R)5"0$BT70B00DZ-S&__^)1>2+1?2+0`R+`(M`""4`
M!```A<!T$(M%](M`#(L`BT`,B474ZSV+1?2+0`R+&,<$)`````#HD<C__XL`
MB00DZ'?%___'1"0,`@```,=$)`@`````B5PD!(D$).C+R/__B474H>Q8!0B+
M$(M%Y(E$)`R+1=2)1"0(B50D!,<$))S:!`CHD\?__Z'D6`4(QT0D!.T!``")
M!"3H[L/__XE%Y(-]Y`!T-(-]Y!%T+H-]Y/]T*(L5Y%@%"*'L6`4(BPB+1>2)
M1"0,B50D"(E,)`3'!"3,V@0(Z$''__^#Q$!;7EW#58GE@^P8QP0D`````.C8
MQ___BP")!"3HOL3__XD$).CVR/__QP0D`````.BZQ___BP")!"3HH,3__\=$
M)!0`````QT0D$!K:!`C'1"0,&MH$",=$)`B>S@0(QT0D!!K;!`B)!"3H4,7_
M_\G#C4PD!(/D\/]Q_%6)Y5&#[#2)3>B+1>B#P`B)1"0(BT7H@\`$B40D!(M%
MZ(D$).@KQ___QT0D"*27!`C'1"0$I)<$",<$)'29!`CHFP(``,<$)`````#H
M0\3__P^V`(3`=4WH)\3__Z/@6`4(H>!8!0B%P'4,QP0D`0```.@]Q___H>!8
M!0B)!"3HT,3__\<$)`````#HY,;__XL`B00DZ,K#__^)!"3H,L;__\8``,<$
M)`````#HP\;__XL`B00DZ*G#__^)!"3HP<;__XG"#[8"@\@"B`+'!"0`````
MZ)O&__^+`(D$).B!P___B00DZ)G&__^)P@^V`H/(`8@"BU7HBP*#P`6Z````
M`%)0WRPDC60D"-GNWL'=!3C;!`C9R=KIW^">#Y?`@_`!A,!U#,<$)*1(!0CH
MDL7__XM5Z(L"@\`%P>`"B00DZ)_%__^C[%@%"(L5[%@%"(M-Z(M!!(L`B0*A
M[%@%"(/`!,<`+]L$"*'L6`4(@\`(QP!@VP0(QP7H6`4(`P```(L5[%@%"*'H
M6`4(P>`"C00"QP`RVP0(H>A8!0B#P`&CZ%@%",=%]`$```#K-8L-[%@%"*'H
M6`4(`T7TB<*X`0```"G0P>`"]]@!P8M%Z(M0!(M%],'@`HT$`HL`B0&#1?0!
MBU7HBP(Y1?1\P8L-[%@%"(M%Z(L0H>A8!0B-!`*)PK@!````*=#!X`+WV(T$
M`<<``````(L-[%@%"(M%Z(L0H>A8!0B-!`*#Z`&+%>!8!0C'1"00`````(E,
M)`R)1"0(QT0D!,K3!`B)%"3H`L'__XE%^(-]^`!U$*'@6`4(B00DZ)S!__^)
M1?BAX%@%"(D$).B<P___QP0D(-D$".A9R/__A<!U,*'D6`4(A<!U$<<$)/'8
M!`CH0,C__Z/D6`4(H>18!0B%P'0-H>18!0B)!"3H=O3__Z'@6`4(B00DZ'_`
M___H.L+__XM%^(/$-%E=C6'\PY"0D)"0D)"0D)!5B>53Z#(```"!PP-P``"#
M[!"+@T@!``")1"0,BT40B40D"(M%#(E$)`2+10B)!"3HS\#__X/$$%M=PXL<
M),.058GE7<.-="8`C;PG`````%6)Y5=64^C@____@<.Q;P``@^P,Z'N___^-
MN_#^__^-@_#^__\IQ\'_`H7_="0Q]HM%$(E$)`B+10R)1"0$BT4(B00D_Y2S
M\/[__X/&`3G^<MZ#Q`Q;7E]=PY"0D)"0D%6)Y5.#[`R+10SH?/___X'#36\`
M`,<$)`,```")1"0(BT4(B40D!.CHO___@\0,6UW#D)"0D)"0D)"0D)"0D)!5
MB>53@^P,BT4,Z#S___^!PPUO``#'!"0#````B40D"(M%"(E$)`3HR,#__X/$
M#%M=PY"0D)"0D)"0D)"0D)"058GE4X/L!*$<1@4(@_C_=!.['$8%"&:0@^L$
M_]"+`X/X_W7T@\0$6UW#D)!5B>53@^P$Z`````!;@<.D;@``Z,S#__]96\G#
M```````````#`````0`"`'!E<FQX<VDN8P!$>6YA3&]A9&5R.CIB;V]T7T1Y
M;F%,;V%D97(`+W!R;V,O<V5L9B]E>&4`+P`Z`&5X90`O<')O8R\E:2\E<P!0
M05)?5$5-4`!005)?4%)/1TY!344`+@`E<R5S)7,`4$%27TE.251)04Q)6D5$
M`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!
M4E]!4D=#`%!!4E]!4D=67S``4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,
M7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,
M7T-,14%.`%!!4E]#3$5!3CT`,0```%]?14Y67U!!4E]#3$5!3E]?("`@("`@
M("`@("`@("`@``!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)205)97U!!
M5$@`4$%42`!$64Q$7TQ)0E)!4EE?4$%42```0SI<5$5-4``O=&UP`%1-4$1)
M4@!414U01$E2`%1%35``5$U0`%5315(`55-%4DY!344`<&%R+0!365-414T`
M)7,E<R5S)7,`)7,E<V-A8VAE+25S)7,`)3`R>``E<R5S=&5M<"TE=25S`"XN
M`"5S+R5S`$%21U8`&`!P97)L`#``)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL
M960@+2!A8F]R=&EN9R!W:71H("5I+@H`)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@=&5M<&]R87)Y('-U8F1I<F5C=&]R>2`E<R!F86EL960@+2!A8F]R=&EN
M9R!W:71H("5I+@H`26YT97)N86QS.CI005(Z.D)/3U0`+64`+2T```````"`
M____ST%P87(N<&P``````````````````````````````````",A+W5S<B]B
M:6XO<&5R;`H*979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE
M;&P*"G!A8VMA9V4@7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T
M(&YO="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S
M92!S=')I8W0["@HC;&EN92`Q-3D*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@
M("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S
M*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE
M.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI
M;FL@?2P@)'!A<E]T96UP*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@(')M
M9&ER("1T;W!D:7(["@H@("`@:68@*"UD("1P87)?=&5M<"D@>PH@("`@("`@
M(",@4V]M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A
M<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA<'!E
M;G,@;VX@<&QA=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H87)E
M9`H@("`@("`@(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R
M92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@(",@
M<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U
M<V4@8GD@=&AI<R!P<F]C97-S+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I
M;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%35!,051%(#T^("=T;7!86%A86"<L
M"B`@("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M=&]P9&ER*2P*("`@("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@
M("`@("`@54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@(R!"96-A
M=7-E('1H92!P87)?=&5M<"!D:7)E8W1O<GD@:7,@9V]I;F<@=&\@8F4@9&5L
M971E9"!I;B!A"B`@("`@("`@(R!B86-K9W)O=6YD('!R;V-E<W,L('1H92!P
M87)E;G0@<')O8V5S<R!I9"!M87D@8F4@<F5U<V5D(&)E9F]R92!T:&4*("`@
M("`@("`C(&)A8VMG<F]U;F0@<')O8V5S<R!C;VUP;&5T97,N("!4;R!E;G-U
M<F4@=&AA="!T:&4@=&5M<&]R87)Y"B`@("`@("`@(R!D:7)E8W1O<GD@9&]E
M<R!N;W0@9V5T(')E=7-E9"!W:&EL92!I="!I<R!B96EN9R!D96QE=&5D+"!T
M<GD@=&\*("`@("`@("`C(')E;F%M92!I="!T;R!A(&YA;64@=&AA="!I<R!R
M96QA=&5D('1O('1H92!T96UP;W)A<GD@<V-R:7!T(&9I;&4N"@H@("`@("`@
M(&UY("1T;7!N86UE(#T@*$9I;&4Z.E-P96,M/G-P;&ET<&%T:"@D=&UP+3YF
M:6QE;F%M92DI6S)=.R`C(&9I;&5N86UE"B`@("`@("`@)'1M<&YA;64@/7X@
M<R]<+EM>+ETJ)"\N9&ER+SL*("`@("`@("!M>2`D;F5W1&ER(#T@1FEL93HZ
M4W!E8RT^8V%T<&%T:"@*("`@("`@("`@("`@*$9I;&4Z.E-P96,M/G-P;&ET
M<&%T:"@D<&%R7W1E;7`I*5LP+BXQ72P@)'1M<&YA;64I.PH@("`@("`@(&EF
M("AR96YA;64@)'!A<E]T96UP+"`D;F5W1&ER*2!["B`@("`@("`@("`@(&]U
M=',H(E)E;F%M960@)'!A<E]T96UP('1O("1N97=$:7(B*3L*("`@("`@("`@
M("`@)'!A<E]T96UP(#T@)&YE=T1I<CL*("`@("`@("!]"@H@("`@("`@(&EF
M("@D7D\@/7X@;2]W:6XS,B]I*2!["B`@("`@("`@("`@('!R:6YT("1T;7`@
M(@HZ;&]O<`IR;61I<B`O<2`O<R!<(B1P87)?=&5M<%PB"FEF(&5X:7-T(%PB
M)'!A<E]T96UP7"(@9V]T;R!L;V]P"G)M9&ER(%PB)'1O<&1I<EPB"G)M(%PB
M(B`N("1T;7`M/F9I;&5N86UE("X@(EPB"B(["B`@("`@("`@("`@(&-L;W-E
M("1T;7`["B`@("`@("`@("`@(&UY("1P<F]C.PH@("`@("`@("`@("!7:6XS
M,CHZ4')O8V5S<SHZ0W)E871E*`H@("`@("`@("`@("`@("`@)'!R;V,L("1%
M3E9[0T]-4U!%0WTL"B`@("`@("`@("`@("`@("`B)$5.5GM#3TU34$5#?2`O
M8R!<(B(@+B`D=&UP+3YF:6QE;F%M92`N(")<(B`^;G5L(#(^;G5L("(L"B`@
M("`@("`@("`@("`@("`Q+"!.3U)-04Q?4%))3U))5%E?0TQ!4U,L("(N(@H@
M("`@("`@("`@("`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!R
M:6YT("1T;7`@(B,A+V)I;B]S:`IW:&EL92!;("UD("<D<&%R7W1E;7`G(%T[
M(&1O"B`@(')M("UR9B`G)'!A<E]T96UP)PID;VYE"G)M9&ER("<D=&]P9&ER
M)PIR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@("`@
M8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@("`@("`@("`@;7D@)&-M
M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@
M("`@("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@("`@('-Y<W1E;2@D8VUD
M*3L*("`@("`@("!]"B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`I*3L*("`@('T*?2!]"@I"
M14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@
M)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET
M7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6
M>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%2
M1U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@
M)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6
M*2!["B`@("`@("`@9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*
M("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX
M("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@
M*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S
M971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I
M;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[
M>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L
M(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@
M)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@
M("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L
M("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN
M(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L
M(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#([
M"B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@
M9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@
M("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@
M;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@
M("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X
M="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@
M("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I
M(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@
M("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D
M8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@
M(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B
M=68["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@
M("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F
M:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D
M('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D
M14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T
M<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@
M)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B
M:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@
M("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@
M("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@
M("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL
M;F%M92P*("`@("`@("`@("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?
M1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@
M/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@
M("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@
M("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO
M9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@
M("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@
M("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@
M("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D[
M"B`@("`@("`@?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@
M/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O
M<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E
M96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@
M("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M
M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@
M("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D
M;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[
M8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE
M("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E
M='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)
M3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@
M("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@
M<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@
M(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@
M("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M
M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S
M="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H
M<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L
M("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R
M)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA
M;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L
M97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@
M*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R
M97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I
M=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE
M;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L
M87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C
M97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D
M;&]G9F@L("1C86-H95]N86UE*3L*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[
M4$%27T1%0E5'?3L*"B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O
M;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H
M(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F
M)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@
M("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@
M('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@
M("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@;7D@0&%D9%]T;U]I;F,[
M"B`@("!W:&EL92`H0$%21U8I('L*("`@("`@("`D05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("!I9B`H
M)#$@97$@)TDG*2!["B`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R
M.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@
M("`@("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@?0H@("`@("`@(&5L<VEF
M("@D,2!E<2`G02<I('L*("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@
M("`@("`@("`@("1O=70@/2`D,CL*("`@("`@("!]"B`@("`@("`@96QS:68@
M*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@
M("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@("!]"B`@("`@("`@96QS:68@
M*"0Q(&5Q("=Q)RD@>PH@("`@("`@("`@("`D<75I970@/2`Q.PH@("`@("`@
M('T*("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@(&]P
M96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@
M;&]G.B`D(2(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I
M('L*("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("!]"@H@
M("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["B`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?
M5$5-4"=].PH@("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("!R
M97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@(&5X:70["B`@
M("`@("`@?0H@("`@?0H*("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,[
M"GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*
M"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*
M("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?
M7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I
M;&4["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H*("`@
M(&UY("1P87(@/2!S:&EF="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I
M9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@
M)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@
M(&)I;FUO9&4H)&9H*3L*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I
M.PH*("`@("`@("`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@
M*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E860@
M)R1P87(G(&5R<F]R.B`D(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R![
M"B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N
M=',H)TU%5$$N>6UL)RDI('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP
M87(Z)"\O;7,["B`@("`@("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@
M("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@
M("`@("`@?0H@("`@?3L*"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U="!F
M:6QE<R![>WL*("`@(&QO8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@
M)'!A<BD@>PH@("`@("`@(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D
M(3H@)'!A<B(["B`@("`@("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B
M)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP
M,#-<,#`T(CL*("`@('T*"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@
M("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@
M("`@($E/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@
M;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN
M960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@
M7T9(+"`P+"`P.PH@("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@
M(&EF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PH@("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA
M<'!L>2A<)&QO861E<BP@)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@
M*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME
M>7T@;W(@;F5X=#L*("`@("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@
M/7X@+UY;)R)=+SL*("`@("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@
M+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@("`@;7D@)'-E="`](")005)?(B`N
M('5C*"1K97DI("X@(CTD=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA
M9VEC*"`K*7U["B`@("`@("`@("`@("1M86=I8R`N("1S970@+B`H)R`G('@@
M*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@
M('T*("`@("1F:"T^<')I;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@
M("`@(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@
M(&EF("@D8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@
M("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@
M("!I;FET7VEN8R@I.PH@("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@
M("`@("!M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@
M/#T^(&QE;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`A
M+T)31%!!3B\*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L
M92!N92`G<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@
M("`@("`@:68@*"1#;VYF:6=[7V1E;&EM?2!E<2`G7%PG*2![('-[7%Q]>R]]
M9R!F;W(@0&EN8R!]"@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\
M*"XK*20O(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@
M("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY
M("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S
M*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@
M("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@("!I
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@
M("`@("`@("`@("`@("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@
M("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L
M<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@
M("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@
M("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@
M)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T
M("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@
M("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI
M;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@
M("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@("`@
M("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL92DI
M('L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@
M("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D
M9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@
M("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@
M("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@
M("`@("`@("`@("`@("!I9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M
M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@(R!$
M;R!N;W0@;&5T(%A33&]A9&5R('!I8VL@=7`@875T;R\J(&9R;VT@96YV:7)O
M;FUE;G0*("`@("`@("`@("`@("`@("1C;VYT96YT(#U^(',O9V]T;R`K<F5T
M<GD@*W5N;&5S<R`K+BHO9V]T;R!R971R>3LO"B`@("`@("`@("`@("`@("`@
M("`@:68@;&,H)&YA;64I(&5Q(&QC*")84TQO861E<BYP;2(I.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE
M(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@
M("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D[
M"B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@
M("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O
M;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I*3L*("`@("`@("`@("`@)&9H
M+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@
M("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@
M("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I
M8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H
M*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N
M86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]
M"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@
M1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@
M("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N
M9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E
M<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R
M<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@
M("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I
M.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@:68@*"1C
M='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@
M("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL
M92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@
M)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA
M;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D
M8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?
M;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L
M96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB
M*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@
M(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE
M(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@
M(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ
M3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D
M24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<[
M"B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@
M07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%2
M7U1%35!](BDI.PH*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![
M(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0H@("`@("`@(&9O<F5A
M8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@("`@("`@
M(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@("`@("`@("`@(&UY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PH@("`@("`@("`@
M("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*("`@("`@("`@("`@
M("`@(%X*("`@("`@("`@("`@("`@("\_<VAL:6(O"B`@("`@("`@("`@("`@
M("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@
M("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@("`@
M("`@("`@("A;7B]=*RD*("`@("`@("`@("`@("`@("0*("`@("`@("`@("`@
M?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T7VYA;64@/2`D,3L*("`@("`@
M("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PH@("`@("`@("`@("!I9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN9R`B
M)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E
M<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*
M("`@("`@("`@("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N
M86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M
M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,
M:6)#86-H97LD<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`
M05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM
M;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*
M(R!]?7T*"G-U8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*
M("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S
M96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R
M<V4H)&YA;64L("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0
M871H.PH@("`@"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@
M<F5Q=6ER95]M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`]
M(%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L
M:6(["B`@("!R97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G
M97(["B`@("!R97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,[
M"B`@("!R97%U:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@("!R97%U
M:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@
M(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*
M("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@
M(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@
M("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E
M.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V
M>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@
M(&5V86P@>R!R97%U:7)E(%=I;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!7
M:6XS,CHZ4')O8V5S<R!].PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5
M=&EL('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R
M<W0@?3L*?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A<'!E87)S
M(&EN(&UY;&1R+VUK=&UP9&ER+F,*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@
M:68@*"1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*("`@("`@("`D<&%R7W1E;7`@/2`D,3L*("`@("`@("!R971U<FX[
M"B`@("!]"@H@("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"B`@("`@("`@<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@("`I('L*
M("`@("`@("!N97AT('5N;&5S<R`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@("`@("!M>2`D<'=U
M:60["B`@("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@
M("`@979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D
M/CM].PH*("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I
M("D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M
M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN960@)'!W=6ED*2![
M"B`@("`@("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*("`@("`@("!]"B`@
M("`@("`@96QS92!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1%3E9[55-%
M4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["B`@("`@("`@?0H@
M("`@("`@("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T
M;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M)'5S97)N86UE(CL*
M("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H(21%
M3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE
M*2E;.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G
M;F%M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L(#(["B`@("`@("`@
M("`@('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@("`@("!I9B`H
M)&)U9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@("`@("`@('-E96L@)&9H
M+"`M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R96%D("1F:"P@)&)U9BP@
M-#$["B`@("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<["B`@("`@("`@
M("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N
M("1B=68["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@
M("`@("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI3
M2$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("`@("`@("`@
M('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q
M+3YN97<@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@("`@
M("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS
M."!A;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@
M("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E
M<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@("`@)&-T>"T^
M861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@
M("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@
M("`@?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PH@("`@
M("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA<W0["B`@("!]
M"@H@("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL92!["B`@
M("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L("1F:6QE;F%M
M92D["@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["@H@
M("`@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N;&EN:R`D9FEL
M96YA;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@0'1M<&9I;&4L
M("1F:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@(')E='5R;B`H
M=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["B`@("!]"@H@
M("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@(&)I
M;FUO9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D["GT*"G-U
M8B!?<V5T7W!R;V=N86UE('L*("`@(&EF("@D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@("`D
M<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P.PH*
M("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D
M14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@
M>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*
M("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@("`@
M("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@("`@
M("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@("`@
M<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D:7(@
M*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![
M"B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D
M:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O
M;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S
M="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@("`@
M("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@
M('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA;64@
M?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N86UE
M(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@(",@
M6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@("`@
M("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'
M971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#
M;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N.PH@
M("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@/2`R
M.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@(&1E
M;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!435!$
M25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%27R<N
M)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N(#T@
M(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I9B`H
M)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%
M04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,
M7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L
M96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM005)?
M0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*
M("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*("`@
M(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB.PH@
M("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@?0I]
M"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P=7-H
M($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL
M('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%1H
M92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA9V4@
M;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD
M7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA;64[
M"@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T52
M4D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@
M:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#$W"@I?7T5.1%]?"@``````
M_____P````#_____```````````!`````0````$```"R`@```0```+T"```!
M````QP(```$````%`P```0```#@$```,````!)<$"`T```!\V`0(!````$B!
M!`CU_O]OH(0$"`4````LC00(!@```/R%!`@*````V04```L````0````%0``
M```````#````+$<%"`(```!P`@``%````!$````7````E)0$"!$```!\E`0(
M$@```!@````3````"````/[__V_LDP0(____;P(```#P__]O!I,$"```````
M````````````````````````````````````````````````````````````
M```P1@4(``````````!*EP0(6I<$"&J7!`AZEP0(BI<$")J7!`BJEP0(NI<$
M",J7!`C:EP0(ZI<$"/J7!`@*F`0(&I@$""J8!`@ZF`0(2I@$"%J8!`AJF`0(
M>I@$"(J8!`B:F`0(JI@$"+J8!`C*F`0(VI@$".J8!`CZF`0("ID$"!J9!`@J
MF00(.ID$"$J9!`A:F00(:ID$"'J9!`B*F00(FID$"*J9!`BZF00(RID$"-J9
M!`CJF00(^ID$"`J:!`@:F@0(*IH$"#J:!`A*F@0(6IH$"&J:!`AZF@0(BIH$
M")J:!`BJF@0(NIH$",J:!`C:F@0(ZIH$"/J:!`@*FP0(&IL$""J;!`@ZFP0(
M2IL$"%J;!`AJFP0(>IL$"(J;!`B:FP0(JIL$"+J;!`C*FP0(VIL$".J;!`CZ
MFP0("IP$"!J<!`@``````````-W8!`C?V`0(_____T#;!`BW6@```$=#0SH@
M*%5B=6YT=2`T+C,N,"TT=6)U;G1U,2D@-"XS+C$@,C`P.#`U,#D@*'!R97)E
M;&5A<V4I``!'0T,Z("A58G5N='4@-"XS+C`M-'5B=6YT=3$I(#0N,RXQ(#(P
M,#@P-3`Y("AP<F5R96QE87-E*0``1T-#.B`H56)U;G1U(#0N,RXP+31U8G5N
M='4Q*2`T+C,N,2`R,#`X,#4P.2`H<')E<F5L96%S92D``$=#0SH@*%5B=6YT
M=2`T+C,N,"TT=6)U;G1U,2D@-"XS+C$@,C`P.#`U,#D@*'!R97)E;&5A<V4I
M``!'0T,Z("A58G5N='4@-"XS+C`M-'5B=6YT=3$I(#0N,RXQ(#(P,#@P-3`Y
M("AP<F5R96QE87-E*0``1T-#.B`H56)U;G1U(#0N,RXP+31U8G5N='4Q*2`T
M+C,N,2`R,#`X,#4P.2`H<')E<F5L96%S92D``$=#0SH@*%5B=6YT=2`T+C,N
M,"TT=6)U;G1U,2D@-"XS+C$@,C`P.#`U,#D@*'!R97)E;&5A<V4I``!'0T,Z
M("A58G5N='4@-"XS+C`M-'5B=6YT=3$I(#0N,RXQ(#(P,#@P-3`Y("AP<F5R
M96QE87-E*0``1T-#.B`H56)U;G1U(#0N,RXP+31U8G5N='4Q*2`T+C,N,2`R
M,#`X,#4P.2`H<')E<F5L96%S92D``$=#0SH@*%5B=6YT=2`T+C,N,"TT=6)U
M;G1U,2D@-"XS+C$@,C`P.#`U,#D@*'!R97)E;&5A<V4I``!'0T,Z("A58G5N
M='4@-"XS+C`M-'5B=6YT=3$I(#0N,RXQ(#(P,#@P-3`Y("AP<F5R96QE87-E
M*0``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N
M<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE
M:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T
M+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````
M```````````````````````````````+`````0````(````4@00(%`$``!,`
M``````````````$`````````$P````<````"````*($$""@!```@````````
M```````$`````````"4````%`````@```$B!!`A(`0``6`,```4`````````
M!`````0````A````]O__;P(```"@A`0(H`0``%P!```%``````````0````$
M````*P````L````"````_(4$"/P%```P!P``!@````$````$````$````#,`
M```#`````@```"R-!`@L#0``V04``````````````0`````````[````____
M;P(````&DP0(!A,``.8````%``````````(````"````2````/[__V\"````
M[),$".P3``"0````!@````(````$`````````%<````)`````@```'R4!`A\
M%```&`````4`````````!`````@```!@````"0````(```"4E`0(E!0``'`"
M```%````#`````0````(````:0````$````&````!)<$"`07```P````````
M```````$`````````&0````!````!@```#27!`@T%P``\`0`````````````
M!`````0```!O`````0````8````PG`0(,!P``$P\`````````````!``````
M````=0````$````&````?-@$"'Q8```<```````````````$`````````'L`
M```!`````@```*#8!`B@6```>%T`````````````(`````````"#`````0``
M``(````8-@4(&+8```0```````````````0`````````C0````$````#````
M'$8%"!RV```(```````````````$`````````)0````!`````P```"1&!0@D
MM@``"```````````````!`````````";`````0````,````L1@4(++8```0`
M``````````````0`````````H`````8````#````,$8%"#"V``#X````!@``
M```````$````"````*D````!`````P```"A'!0@HMP``!```````````````
M!`````0```"N`````0````,````L1P4(++<``$0!``````````````0````$
M````MP````$````#````<$@%"'"X```<```````````````$`````````+T`
M```(`````P```*!(!0B,N```4!``````````````(`````````#"`````0``
M````````````C+@``'X"``````````````$``````````0````,`````````
<``````J[``#+```````````````!````````````
